
#include "LPC214x.h"


//functions
void initTimer0(void);
void __attribute__ ((interrupt("IRQ"))) T0ISR(void);

//MAIN:
int main(void)
{
    
    initTimer0(); //Initialize Timer0
    IODIR0 = 0xFFFFFFFF; //Configure all pins on Port 0 as Output
	IODIR1 = 0xFFFFFFFF;
	
	IOCLR1 = 0xFFFFFFFF;
	IOCLR0 = 0xFFFFFFFF;
	
	T0TCR = 0x01; //Enable timer
	
	//loop:
    while(1)
    {
	
	//toggle to observe activity of main loop
	if(IOPIN1 && (1<<3)) {IOCLR1=0xFFFFFFFF;}
	else{IOSET1=0xFFFFFFFF;}
	
    }
    
}


// timer setup
void initTimer0(void)
{
  
	VPBDIV = 0x01; // PCLK * VPBDIV = CCLK (60Mhz)
    
	T0CTCR = 0x0;
    T0PR = 60000-1;  //PCLK/T0PR = f_interrupt (1ms) ---- zero index 

    T0MR0 = 4; //
    
	T0MCR = 0x01 | 0x10; //Bit0: interrupt on MR0 = TC, Bit1: reset MR0, Bit2: Stop on MR0=TC. 
	
	 //----------Setup Timer0 Interrupt-------------
	
	VICVectAddr0 = (unsigned )T0ISR; //Pointer Interrupt Function (ISR)
	
	VICVectCntl0 = 0x20 | 4; // Bit5: enable VIQ, Bit4-Bit0 Interrupt type
	VICIntSelect	= 	0;  //FIQ select = 1;
	VICIntEnable = 0x10; //Enable timer0
    T0TCR = 0x02; //Reset Timer
}

// interrupt routine
void __attribute__ ((interrupt("IRQ"))) T0ISR(void)
{
    long int regVal;
	regVal = T0IR; //Read current IR value
	
	//CODE:
	// Just set the all IO0 pins to check interrupt
	IOSET0=0xFFFFFFFF;
	
	
	T0IR = regVal; //Write back to IR to clear Interrupt Flag
	VICVectAddr = 0x0; //This is to signal end of interrupt execution
}

/*


Tabela:
WDT		N/A		Core	Core	Timer0	Timer1	Uart0	Uart1	PWM		I2C0	SPI0	SPI1
0		1		2		3		4		5		6		7		8		9		10		11
0X00	0X01	0X02	0X03	0X04	0X05	0X06	0X07	0X08	0X09	0X0A	0X0B

PLL		RTC		EINT0	EINT1	EINT2	EINT3	ADC0	I2C1	BOD		ADX		USB	
12		13		14		15		16		17		18		19		20		21		22	
0X0C	0X0D	0X0E	0X0F	0X10	0X11	0X12	0X13	0X14	0X15	0X16	


VICIntSelect	= 	0;						//Izberi, kateri interr. je FIQ(1) in kateri IRQ(0). Default 0, samo en interrupt je lahko FIQ (best practice). 
VICIntEnable	|= 	(1<<4); 				//vkljui posamezne interrupte (glej tabelo)			//
//VICVectCntl0 --> VICVectCntl15			//Sloti za vektorkse interuupte. 0 je najvija prioriteta. VICVectCntl0 	= 	(1<<5) | 4; 			//
VICVectCntl0	=	(1<<5) | 4;				//Struktura registra: biti b0-b4 definirajo tip interrupta (tabela), bit 5 enabla vektorsji IRQ na temu slotu (vpii 1)

//VICVectAddr0 to VICVectAddr15				//registeri kaejo na naslov funkcije, ki se izvri ob interr. 
//VICVectAddr								//register ki spravi naslov ISRja, ki je trenutno aktiven. e napie noter dummy, signalizira da se je ISR konal.
//VICDefVectAddr							//default/common ISR addr za Non-Vectored IRQ.  


//VICIntEnClr 								// register za izkljuitev interruptov. 1 disabla
//VICSoftInt								// soft interrupt. Dvigni pin v registru za sproitev int.
//VICSoftIntClear							// soft interr. clear. 1 sprosti (clear-a) interrupt.

//VICIRQStatus								//statusni register za IRQ
//VICFIQStatus								//statusni register za FIQ



*/
